#ifndef _DL_HPP_
#define _DL_HPP_

#include <iostream>
#include <vector>

class DL2 // La classe correspondant aux développements limités de la forme f0 + f1x + o(x)

{
private:
  double f0;
  double f1;
  
public:
  DL2(double f, double df=0) : f0(f), f1(df) {} // Le constructeur de la classe, qui prend en argument les deux valeurs correspondant à f0 et f1.
  
  
  friend std::ostream& operator<<(std::ostream &, DL2 const&); // Affichage

  // Les quatre opérations
  friend DL2 operator+(DL2 const&, DL2 const&);
  friend DL2 operator-(DL2 const&, DL2 const&);
  friend DL2 operator*(DL2 const&, DL2 const&);
  friend DL2 operator/(DL2 const&, DL2 const&);
};

const DL2 x(0,1); // Une constante correspondant au développement limite x + o(x)


class DL // La classe correspondant aux développements limités de longueur arbitraire
{
private:
  int ordre;
  std::vector<double> coefs; // Les coefficients sont stockés dans un vecteur
  
public:
  DL(double f0, int o=100) : ordre(o), coefs(o+1,0) {
	coefs[0]=f0; // Ce constructeur remplit le tableau de coefficients avec [f0,0,0,...,0]
  }
  DL(std::vector<double> const&coefs0) : ordre(coefs0.size()-1), coefs(coefs0) {} // Un constructeur qui prend en argument un vecteur de coefficients.
  
  friend std::ostream& operator<<(std::ostream &, DL const&); // Affichage

  // Les quatre opérations
  friend DL operator+(DL const&, DL const&);
  friend DL operator-(DL const&, DL const&);
  friend DL operator*(DL const&, DL const&);
  friend DL operator/(DL const&, DL const&);

  DL operator()(DL const&); // La composition de deux développements
  
};

  



#endif
