#include <iostream> // Pour pouvoir afficher le résultat
#include <random>   // Pour simultes des variables aléatoires

const int N = 10; // La constante N de l'énoncé
const int MC = 1000000; // Le nombre de simulations pour calculer P(X_tau=0)


int main(void)
{
  std::mt19937 G(56783); // On initialise le générateur aléatoire
  std::uniform_int_distribution<int> U(0,1); // Une variable prenant les valeurs 0 et 1, chacune avec probabilité 1/2.
  
  for (int X0=0; X0<=N; X0++) // On fait une boucle sur tous les états initiaux possibles
	{
	  int compte = 0; // Pour chaque condition initiale, on compte le nombre de simulations qui quittent l'intervalle par 0 plutôt que par 1.

	  for (int k=0; k<MC; k++) // On fait MC simulations.
		{
		  int Xn = X0;
		  
		  while (Xn!=0 and Xn!=N)
			Xn += 2*U(G)-1; //2*U(G)-1 prend les valeurs 1 ou -1, avec probabilité 1/2
		  
		  if (Xn==0)
			compte ++;
		}
	  
	  std::cout << "P(X_tau = 0 | X0 = " << X0 << ") ~ " << compte/(double)MC << "\n";
	  // La valeur théorique de P(X_tau=0) partant de x0 est 1-x0/N.
	}

  return 0;
}
